![GitHub repo size](https://img.shields.io/github/repo-size/pacotei/flask-vuejs) ![GitHub top language](https://img.shields.io/github/languages/top/pacotei/flask-vuejs) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/flask-vuejs)
![GitHub](https://img.shields.io/github/license/pacotei/flask-vuejs?style=flat-square)

Documentation: https://flaskvue.pacotei.xyz/
